@@ -16,8 +16,6 @@ BEGIN {
     }
 }
 
-use constant NS => 'http://purl.org/atom/ns#';
-
 sub init {
     my $atom = shift;
     my %param = @_ == 1 ? (Stream => $_[0]) : @_;
@@ -93,12 +91,12 @@ sub version {
     if (@_) {
         $elem->setAttribute('version', $_[0]);
     }
-    $elem->getAttribute('version');
+    $elem->getAttribute('version') || $feed->SUPER::version(@_);
 }
 
 sub entries_libxml {
     my $feed = shift;
-    my @res = $feed->{doc}->getElementsByTagNameNS(NS, 'entry') or return;
+    my @res = $feed->{doc}->getElementsByTagNameNS($feed->ns, 'entry') or return;
     my @entries;
     for my $res (@res) {
         my $entry = XML::Atom::Entry->new(Elem => $res->cloneNode(1));
@@ -109,13 +107,13 @@ sub entries_libxml {
 
 sub entries_xpath {
     my $feed = shift;
-    my $set = $feed->{doc}->find("descendant-or-self::*[local-name()='entry' and namespace-uri()='" . NS . "']");
+    my $set = $feed->{doc}->find("descendant-or-self::*[local-name()='entry' and namespace-uri()='" . $feed->ns . "']");
     my @entries;
     for my $elem ($set->get_nodelist) {
         ## Delete the link to the parent (feed) element, and append
         ## the default Atom namespace.
         $elem->del_parent_link;
-        my $ns = XML::XPath::Node::Namespace->new('#default' => NS);
+        my $ns = XML::XPath::Node::Namespace->new('#default' => $feed->ns);
         $elem->appendNamespace($ns);
         my $entry = XML::Atom::Entry->new(Elem => $elem);
         push @entries, $entry;
@@ -125,14 +123,29 @@ sub entries_xpath {
 
 sub add_entry_libxml {
     my $feed = shift;
-    my($entry) = @_;
-    $feed->{doc}->getDocumentElement->appendChild($entry->{doc}->getDocumentElement);
+    my($entry, $opt) = @_;
+    $opt ||= {};
+    if ($opt->{mode} && $opt->{mode} eq 'insert') {
+        $feed->{doc}->getDocumentElement->insertBefore(
+            $entry->{doc}->getDocumentElement,
+            $feed->{doc}->getDocumentElement->firstChild,
+        );
+    } else {
+        $feed->{doc}->getDocumentElement->appendChild(
+            $entry->{doc}->getDocumentElement,
+        );
+    }
 }
 
 sub add_entry_xpath {
     my $feed = shift;
-    my($entry) = @_;
-    $feed->{doc}->appendChild($entry->{doc});
+    my($entry, $opt) = @_;
+    $opt ||= {};
+    if ($opt->{mode} && $opt->{mode} eq 'insert') {
+        $feed->{doc}->insertBefore($entry->{doc}, $feed->{doc}->getFirstChild);
+    } else {
+        $feed->{doc}->appendChild($entry->{doc});
+    }
 }
 
 1;
@@ -152,6 +165,8 @@ XML::Atom::Feed - Atom feed
     $entry->title('First Post');
     $entry->content('Post Body');
     $feed->add_entry($entry);
+    $feed->add_entry($entry, { mode => 'insert' });
+
     my @entries = $feed->entries;
     my $xml = $feed->as_xml;
 
@@ -231,6 +246,17 @@ the feed as a new I<E<lt>linkE<gt>> tag. For example:
     $link->href('http://www.example.com/');
     $feed->add_link($link);
 
+=head2 $feed->add_entry($entry)
+
+Adds the entry I<$entry>, which must be an I<XML::Atom::Entry> object,
+to the feed. If you want to add an entry before existent entries, you can pass optional hash reference containing C<mode> value set to C<insert>.
+
+  $feed->add_entry($entry, { mode => 'insert' });
+
+=head2 $feed->entries
+
+Returns list of XML::Atom::Entry objects contained in the feed.
+
 =head2 $feed->language
 
 Returns the language of the feed, from I<xml:lang>.
